unit Girder;

interface

uses Windows, SysUtils, GirderAPI, Forms, StrUtils;

type
  tgir_open = function(gir_major_ver, gir_minor_ver, gir_micro_ver: integer; api_functions: p_functions): integer; stdcall;
  tgir_close = function: integer; stdcall;
  tgir_start = function: integer; stdcall;
  tgir_stop = function: integer; stdcall;
  tgir_config = procedure; stdcall;
  tgir_requested_api = function(max_api: integer): integer; stdcall;
  tgir_name = procedure(data: PCHAR; len: integer); stdcall;
  tgir_version = procedure(data: PCHAR; len: integer); stdcall;
  tgir_description = procedure(data: PCHAR; len: integer); stdcall;
  tgir_devicenum = function: integer; stdcall;

  tgirdll = record
    libh: THandle;
    ver, name, descr: array[0..100] of char;
    devnum, reqapi: integer;
    gir_open: tgir_open;
    gir_close: tgir_close;
    gir_start: tgir_start;
    gir_stop: tgir_stop;
    gir_config: tgir_config;
    gir_requested_api: tgir_requested_api;
    gir_name: tgir_name;
    gir_version: tgir_version;
    gir_description: tgir_description;
    gir_devicenum: tgir_devicenum;
  end;

  tcallbackprc = procedure(vCode: Integer);
  pcallbackprc = ^tcallbackprc;

const
  gir_major_ver = 3;
  gir_minor_ver = 3;
  gir_micro_ver = 7;

var
  vfunc: t_functions;
  CallBackProc: tcallbackprc;
  GirderModuleName: string;

function openlib(var l: tgirdll): boolean;
procedure closelib(var l: tgirdll);
procedure fill_s_func(h: HWnd);

implementation

procedure DoMes(event: string);
begin
  try CallBackProc(H2D(event))except end;
end;

function ltranslate(orig: PChar; store: PChar; size: Integer): Integer; stdcall;
begin
  Result := GIR_FALSE;
end;

function lsendevent(eventstring: PChar; payload: pbytearray; len: Integer; device: Integer): Integer; stdcall;
begin
  DoMes(eventstring);
  Result := GIR_TRUE;
end;

procedure fill_s_func(h: HWnd);
begin
  fillchar(vfunc, sizeof(vfunc), 0);
  with vfunc do begin
    size := sizeof(vfunc);
    i18n_translate := @ltranslate;
    send_event := @lsendevent;
    parent_hwnd := h;
  end;
end;

function openlib(var l: tgirdll): boolean;
var DllName: string;
begin
  result := false;
  DllName := GirderModuleName;
  with l do begin
    libh := LoadLibrary(PChar(DllName));
    if libh = 0 then exit;

    gir_open := GetProcAddress(libh, 'gir_open'); {ok}
    gir_close := GetProcAddress(libh, 'gir_close'); {ok}
    if (@gir_open = nil) or
      (@gir_close = nil) then
    begin
      closelib(l);
      exit;
    end;
    gir_start := GetProcAddress(libh, 'gir_start'); {ok}
    gir_stop := GetProcAddress(libh, 'gir_stop'); {ok}
    gir_config := GetProcAddress(libh, 'gir_config'); {ok!}
    gir_requested_api := GetProcAddress(libh, 'gir_requested_api'); {ok}
    gir_name := GetProcAddress(libh, 'gir_name'); {ok}
    gir_version := GetProcAddress(libh, 'gir_version'); {ok}
    gir_description := GetProcAddress(libh, 'gir_description'); {ok}
    gir_devicenum := GetProcAddress(libh, 'gir_devicenum'); {ok}

    if @gir_version <> nil then gir_version(@ver, sizeof(ver)) else ver[0] := #0;
    if @gir_name <> nil then gir_name(@name, sizeof(name)) else name[0] := #0;
    if @gir_description <> nil then gir_description(@descr, sizeof(descr)) else descr[0] := #0;

    if @gir_devicenum <> nil then devnum := gir_devicenum else devnum := -1;
    if @gir_requested_api <> nil then reqapi := gir_requested_api(1 {apiver}) else reqapi := -1;
    fill_s_func(Application.Handle);
    if @gir_open <> nil then
      if gir_open(gir_major_ver, gir_minor_ver, gir_micro_ver, @vfunc) = GIR_FALSE then begin
        closelib(l);
        exit;
      end;
    if @gir_start <> nil then
      if gir_start = GIR_FALSE then begin
        closelib(l);
        exit;
      end;
  end;
  Result := true;
end;

procedure closelib(var l: tgirdll);
begin
  with l do begin
    if @gir_stop <> nil then gir_stop;
    //if @gir_close <> nil then gir_close;
    FreeLibrary(libh);
  end;
end;

end.

